Class: Fastlane::Helper::MemoryLeakDetectorHelper
- Inherits:
-
Object
- Object
- Fastlane::Helper::MemoryLeakDetectorHelper
- Defined in:
- lib/fastlane/plugin/memory_leak_detector/helper/memory_leak_detector_helper.rb
Class Method Summary collapse
-
.show_message ⇒ Object
class methods that you define here become available in your action as
Helper::MemoryLeakDetectorHelper.your_method.
Class Method Details
.show_message ⇒ Object
class methods that you define here become available in your action as Helper::MemoryLeakDetectorHelper.your_method
11 12 13 |
# File 'lib/fastlane/plugin/memory_leak_detector/helper/memory_leak_detector_helper.rb', line 11 def self. UI.("Hello from the memory_leak_detector plugin helper!") end |